@@ -6,8 +6,11 @@
 #include "message-dialogs.h"
 #include "add-common.h"
 #include "get-builder.h"
+#include "common/common.h"
+#include "gui-common.h"
 
-typedef struct _gtimeout_data {
+
+typedef struct gtimeout_data_t {
     GtkWidget *diag;
     gboolean uris_available;
     gboolean image_available;
@@ -16,61 +19,51 @@ typedef struct _gtimeout_data {
     AppData * app_data;
 } GTimeoutCBData;
 
-static gboolean check_result             (gpointer data);
+static gboolean check_result             (gpointer       data);
 
 static void     parse_file_and_update_db (const gchar   *filename,
-                                          AppData       *app_data);
+                                          AppData       *app_data,
+                                          gboolean       google_migration);
 
 static void     uri_received_func        (GtkClipboard  *clipboard,
                                           gchar        **uris,
                                           gpointer       user_data);
 
-static void     image_received_func (GtkClipboard       *clipboard,
-                                     GdkPixbuf          *pixbuf,
-                                     gpointer            user_data);
+static void     image_received_func      (GtkClipboard  *clipboard,
+                                          GdkPixbuf     *pixbuf,
+                                          gpointer       user_data);
 
 
 void
-add_qr_from_file (GSimpleAction *simple    __attribute__((unused)),
+add_qr_from_file (GSimpleAction *simple,
                   GVariant      *parameter __attribute__((unused)),
                   gpointer       user_data)
 {
+    const gchar *action_name = g_action_get_name (G_ACTION(simple));
+    gboolean google_migration = (g_strcmp0 (action_name, GOOGLE_MIGRATION_FILE_ACTION_NAME) == 0) ? TRUE : FALSE;
+
     AppData *app_data = (AppData *)user_data;
 
-#if GTK_CHECK_VERSION(3, 20, 0)
     GtkFileChooserNative *dialog = gtk_file_chooser_native_new ("Open File",
                                                      GTK_WINDOW (app_data->main_window),
                                                      GTK_FILE_CHOOSER_ACTION_OPEN,
                                                      "Open",
                                                      "Cancel");
-#else
-    GtkWidget *dialog = gtk_file_chooser_dialog_new ("Open File",
-                                                     GTK_WINDOW (app_data->main_window),
-                                                     GTK_FILE_CHOOSER_ACTION_OPEN,
-                                                     "Cancel", GTK_RESPONSE_CANCEL,
-                                                     "Open", GTK_RESPONSE_ACCEPT,
-                                                     NULL);
-#endif
+
     GtkFileFilter *filter = gtk_file_filter_new ();
     gtk_file_filter_set_name (filter, "QR Image (*.png)");
     gtk_file_filter_add_pattern (filter, "*.png");
     gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
 
-#if GTK_CHECK_VERSION(3, 20, 0)
     gint res = gtk_native_dialog_run (GTK_NATIVE_DIALOG (dialog));
-#else
-    gint res = gtk_dialog_run (GTK_DIALOG (dialog));
-#endif
+
     if (res == GTK_RESPONSE_ACCEPT) {
         gchar *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
-        parse_file_and_update_db (filename, app_data);
+        parse_file_and_update_db (filename, app_data, google_migration);
         g_free (filename);
     }
-#if GTK_CHECK_VERSION(3, 20, 0)
+
     g_object_unref (dialog);
-#else
-    gtk_widget_destroy (dialog);
-#endif
 }
 
 
@@ -130,7 +123,8 @@ check_result (gpointer data)
 
 static void
 parse_file_and_update_db (const gchar *filename,
-                          AppData     *app_data)
+                          AppData     *app_data,
+                          gboolean     google_migration)
 {
     gchar *otpauth_uri = NULL;
     gchar *err_msg = parse_qrcode (filename, &otpauth_uri);
@@ -140,13 +134,14 @@ parse_file_and_update_db (const gchar *filename,
         return;
     }
 
-    err_msg = add_data_to_db (otpauth_uri, app_data);
+    err_msg = parse_uris_migration (app_data, otpauth_uri, google_migration);
     if (err_msg != NULL) {
         show_message_dialog (app_data->main_window, err_msg, GTK_MESSAGE_ERROR);
         g_free (err_msg);
     } else {
-        show_message_dialog (app_data->main_window, "QRCode successfully imported from the screenshot", GTK_MESSAGE_INFO);
+        show_message_dialog (app_data->main_window, "QRCode successfully scanned", GTK_MESSAGE_INFO);
     }
+
     gcry_free (otpauth_uri);
 }
 
@@ -157,12 +152,27 @@ uri_received_func (GtkClipboard  *clipboard __attribute__((unused)),
                    gpointer       user_data)
 {
     AppData *app_data = (AppData *)user_data;
+    GdkPixbuf *pbuf;
+    GError *err = NULL;
     if (uris != NULL && uris[0] != NULL) {
-        gint len_fpath = g_utf8_strlen (uris[0], -1) - 7 + 1; // -7 is for file://
+        glong len_fpath = g_utf8_strlen (uris[0], -1) - 7 + 1; // -7 is for file://
         gchar *file_path = g_malloc0 (len_fpath);
         memcpy (file_path, uris[0] + 7, len_fpath);
-        parse_file_and_update_db (file_path, app_data);
+        pbuf = gdk_pixbuf_new_from_file (file_path, &err);
         g_free (file_path);
+        if (err != NULL) {
+            gchar *msg = g_strconcat ("Couldn't get QR code URI from clipboard: ", err->message, NULL);
+            show_message_dialog (app_data->main_window, msg, GTK_MESSAGE_ERROR);
+            g_free (msg);
+        } else {
+            // here we convert the input file to a PNG file, so we are able to parse it later on.
+            gchar *filename = g_build_filename (g_get_tmp_dir (), "qrcode_from_cb_uri.png", NULL);
+            gdk_pixbuf_save (pbuf, filename, "png", &err, NULL);
+            parse_file_and_update_db (filename, app_data, FALSE);
+            g_unlink (filename);
+            g_free (filename);
+            g_object_unref (pbuf);
+        }
     } else {
         show_message_dialog (app_data->main_window, "Couldn't get QR code URI from clipboard", GTK_MESSAGE_ERROR);
     }
@@ -184,11 +194,11 @@ image_received_func (GtkClipboard  *clipboard __attribute__((unused)),
             show_message_dialog (app_data->main_window, msg, GTK_MESSAGE_ERROR);
             g_free (msg);
         } else {
-            parse_file_and_update_db (filename, app_data);
+            parse_file_and_update_db (filename, app_data, FALSE);
         }
         g_unlink (filename);
         g_free (filename);
     } else {
         show_message_dialog (app_data->main_window, "Couldn't get QR code image from clipboard", GTK_MESSAGE_ERROR);
     }
-}
+}
\ No newline at end of file
