@@ -8,7 +8,7 @@
 #include "gquarks.h"
 #include "common/common.h"
 
-typedef struct _header_data {
+typedef struct header_data_t {
     guint8 iv[IV_SIZE];
     guint8 salt[KDF_SALT_SIZE];
 } HeaderData;
@@ -100,6 +100,22 @@ update_and_reload_db (AppData       *app_data,
 }
 
 
+void
+load_new_db (AppData  *app_data,
+             GError  **err)
+{
+    reload_db (app_data->db_data, err);
+    if (*err != NULL) {
+        return;
+    }
+#ifdef BUILD_GUI
+    update_model (app_data);
+    g_slist_free_full (app_data->db_data->data_to_add, json_free);
+    app_data->db_data->data_to_add = NULL;
+#endif
+}
+
+
 gint
 check_duplicate (gconstpointer data,
                  gconstpointer user_data)
@@ -341,7 +357,7 @@ get_derived_key (const gchar    *pwd,
         return SECURE_MEMORY_ALLOC_ERR;
     }
 
-    int ret = gcry_kdf_derive (pwd, pwd_len, GCRY_KDF_PBKDF2, GCRY_MD_SHA512, header_data->salt, KDF_SALT_SIZE, KDF_ITERATIONS, key_len, derived_key);
+    gpg_error_t ret = gcry_kdf_derive (pwd, pwd_len, GCRY_KDF_PBKDF2, GCRY_MD_SHA512, header_data->salt, KDF_SALT_SIZE, KDF_ITERATIONS, key_len, derived_key);
     if (ret != 0) {
         gcry_free (derived_key);
         g_printerr ("Error during key derivation\n");
