@@ -24,7 +24,12 @@ export_data_cb (GSimpleAction *simple,
 #endif
 
     gchar *password = NULL, *exported_file_path = NULL, *ret_msg = NULL;
-    gboolean encrypted = (g_strcmp0 (action_name, "export_andotp") == 0) ? TRUE : FALSE;
+    gboolean encrypted;
+    if ((g_strcmp0 (action_name, "export_andotp") == 0) || (g_strcmp0 (action_name, "export_aegis") == 0)) {
+        encrypted = TRUE;
+    } else {
+        encrypted = FALSE;
+    }
     if (g_strcmp0 (action_name, ANDOTP_EXPORT_ACTION_NAME) == 0 || g_strcmp0 (action_name, ANDOTP_EXPORT_PLAIN_ACTION_NAME) == 0) {
         if (encrypted == TRUE) {
             password = prompt_for_password (app_data, NULL, NULL, TRUE);
@@ -36,9 +41,12 @@ export_data_cb (GSimpleAction *simple,
         exported_file_path = g_build_filename (base_dir, "freeotpplus-exports.txt", NULL);
         ret_msg = export_freeotpplus (exported_file_path, app_data->db_data->json_data);
         show_ret_msg_dialog (app_data->main_window, exported_file_path, ret_msg);
-    } else if (g_strcmp0 (action_name, AEGIS_EXPORT_ACTION_NAME) == 0) {
-        exported_file_path = g_build_filename (base_dir, "aegis_export_plain.json", NULL);
-        ret_msg = export_aegis (exported_file_path, app_data->db_data->json_data);
+    } else if (g_strcmp0 (action_name, AEGIS_EXPORT_ACTION_NAME) == 0 || g_strcmp0 (action_name, AEGIS_EXPORT_PLAIN_ACTION_NAME) == 0) {
+        if (encrypted == TRUE) {
+            password = prompt_for_password (app_data, NULL, NULL, TRUE);
+        }
+        exported_file_path = g_build_filename (base_dir, encrypted == TRUE ? "aegis_encrypted.json" : "aegis_export_plain.json", NULL);
+        ret_msg = export_aegis (exported_file_path, app_data->db_data->json_data, password);
         show_ret_msg_dialog (app_data->main_window, exported_file_path, ret_msg);
     } else {
         show_message_dialog (app_data->main_window, "Invalid export action.", GTK_MESSAGE_ERROR);
