@@ -10,8 +10,11 @@ G_BEGIN_DECLS
 #define AUTHPLUS_IMPORT_ACTION_NAME         "import_authplus"
 #define FREEOTPPLUS_IMPORT_ACTION_NAME      "import_freeotpplus"
 #define AEGIS_IMPORT_ACTION_NAME            "import_aegis"
+#define AEGIS_IMPORT_ENC_ACTION_NAME        "import_aegis_enc"
+#define GOOGLE_MIGRATION_FILE_ACTION_NAME   "import_google_qr_file"
+#define GOOGLE_MIGRATION_WEBCAM_ACTION_NAME "import_google_qr_webcam"
 
-typedef struct _otp_t {
+typedef struct otp_object_t {
     gchar *type;
 
     gchar *algo;
