@@ -1,5 +1,4 @@
 #include <glib.h>
-#include "gui-common.h"
 #include "imports.h"
 #include "common/common.h"
 
@@ -69,23 +68,23 @@ static void
 parse_parameters (const gchar   *modified_uri,
                   otp_t         *otp)
 {
-    const gchar *mod_uri_copy = modified_uri;
-    gchar **tokens = g_strsplit (mod_uri_copy, "?", -1);
+    gchar **tokens = g_strsplit (modified_uri, "?", -1);
     gchar *escaped_issuer_and_label = g_uri_unescape_string (tokens[0], NULL);
-    mod_uri_copy += g_utf8_strlen (tokens[0], -1) + 1; // "issuer:label?"
+    gchar *mod_uri_copy_utf8 = g_utf8_offset_to_pointer(modified_uri, g_utf8_strlen (tokens[0], -1) + 1);
     g_strfreev (tokens);
 
     tokens = g_strsplit (escaped_issuer_and_label, ":", -1);
     if (tokens[0] && tokens[1]) {
         otp->issuer = g_strdup (g_strstrip (tokens[0]));
         otp->account_name = g_strdup (g_strstrip (tokens[1]));
+
     } else {
         otp->account_name = g_strdup (g_strstrip (tokens[0]));
     }
     g_free (escaped_issuer_and_label);
     g_strfreev (tokens);
 
-    tokens = g_strsplit (mod_uri_copy, "&", -1);
+    tokens = g_strsplit (mod_uri_copy_utf8, "&", -1);
     gint i = 0;
     while (tokens[i]) {
         if (g_ascii_strncasecmp (tokens[i], "secret=", 7) == 0) {
