@@ -2,10 +2,9 @@
 #include <zbar.h>
 #include <png.h>
 #include <glib/gstdio.h>
-#include "gui-common.h"
 #include "common/common.h"
 
-typedef struct _image_data_t {
+typedef struct image_data_t {
     gulong width;
     gulong height;
     guchar *raw_data;
@@ -33,11 +32,7 @@ parse_qrcode (const gchar    *png_path,
     }
 
     zbar_image_t *image = zbar_image_create ();
-#ifdef ZBAR_OLD_LIB
-    zbar_image_set_format (image, *(int*)"Y800");
-#else
     zbar_image_set_format (image, zbar_fourcc ('Y','8','0','0'));
-#endif
     zbar_image_set_size (image, image_data->width, image_data->height);
     zbar_image_set_data (image, image_data->raw_data, image_data->width * image_data->height, zbar_image_free_data);
 
@@ -51,7 +46,7 @@ parse_qrcode (const gchar    *png_path,
 
     const zbar_symbol_t *symbol = zbar_image_first_symbol (image);
     for (; symbol; symbol = zbar_symbol_next (symbol)) {
-        *otpauth_uri = secure_strdup (zbar_symbol_get_data (symbol));
+        *otpauth_uri = secure_strdup (g_uri_unescape_string (zbar_symbol_get_data (symbol), NULL));
     }
 
     zbar_image_destroy (image);
