@@ -1,16 +1,16 @@
 #include <gtk/gtk.h>
 #include <zbar.h>
 #include <gcrypt.h>
-#include "gui-common.h"
 #include "imports.h"
 #include "parse-uri.h"
 #include "message-dialogs.h"
 #include "add-common.h"
 #include "get-builder.h"
 #include "common/common.h"
+#include "gui-common.h"
 
 
-typedef struct _config_data {
+typedef struct config_data_t {
     GtkWidget *diag;
     gchar *otp_uri;
     gboolean qrcode_found;
@@ -29,6 +29,9 @@ webcam_cb (GSimpleAction *simple    __attribute__((unused)),
            GVariant      *parameter __attribute__((unused)),
            gpointer       user_data)
 {
+    const gchar *action_name = g_action_get_name (G_ACTION(simple));
+    gboolean google_migration = (g_strcmp0 (action_name, GOOGLE_MIGRATION_WEBCAM_ACTION_NAME) == 0) ? TRUE : FALSE;
+
     AppData *app_data = (AppData *)user_data;
 
     ConfigData *cfg_data = g_new0 (ConfigData, 1);
@@ -36,8 +39,6 @@ webcam_cb (GSimpleAction *simple    __attribute__((unused)),
     GtkBuilder *builder = get_builder_from_partial_path (UI_PARTIAL_PATH);
     cfg_data->diag = GTK_WIDGET(gtk_builder_get_object (builder, "diag_webcam_id"));
 
-    gtk_window_set_transient_for (GTK_WINDOW(cfg_data->diag), GTK_WINDOW(app_data->main_window));
-
     cfg_data->qrcode_found = FALSE;
     cfg_data->gtimeout_exit_value = TRUE;
     cfg_data->counter = 0;
@@ -51,7 +52,7 @@ webcam_cb (GSimpleAction *simple    __attribute__((unused)),
         return;
     }
     zbar_processor_set_data_handler (proc, scan_qrcode, cfg_data);
-    zbar_processor_set_visible (proc, 0);
+    zbar_processor_set_visible (proc, 1);
     zbar_processor_set_active (proc, 1);
 
     guint source_id = g_timeout_add (1000, check_result, cfg_data);
@@ -61,7 +62,8 @@ webcam_cb (GSimpleAction *simple    __attribute__((unused)),
     gint response = gtk_dialog_run (GTK_DIALOG (cfg_data->diag));
     if (response == GTK_RESPONSE_CANCEL) {
         if (cfg_data->qrcode_found) {
-            gchar *err_msg = add_data_to_db (cfg_data->otp_uri, app_data);
+            zbar_processor_destroy (proc);
+            gchar *err_msg = parse_uris_migration (app_data, cfg_data->otp_uri, google_migration);
             if (err_msg != NULL) {
                 show_message_dialog (app_data->main_window, err_msg, GTK_MESSAGE_ERROR);
                 g_free (err_msg);
@@ -70,7 +72,6 @@ webcam_cb (GSimpleAction *simple    __attribute__((unused)),
             }
             gcry_free (cfg_data->otp_uri);
         }
-        zbar_processor_destroy (proc);
         if (cfg_data->gtimeout_exit_value) {
             // only remove if 'check_result' returned TRUE
             g_source_remove (source_id);
@@ -103,7 +104,7 @@ scan_qrcode (zbar_image_t   *image,
     ConfigData *cfg_data = (ConfigData *)user_data;
     const zbar_symbol_t *symbol = zbar_image_first_symbol (image);
     for (; symbol; symbol = zbar_symbol_next (symbol)) {
-        cfg_data->otp_uri = secure_strdup (zbar_symbol_get_data (symbol));
+        cfg_data->otp_uri = secure_strdup (g_uri_unescape_string (zbar_symbol_get_data (symbol), NULL));
         cfg_data->qrcode_found = TRUE;
     }
 }
